@@ -1,6 +1,6 @@
 package Acme::BCARMER;
 
-use 5.006
+use 5.006;
 use strict;
 use warnings;
 
@@ -10,11 +10,11 @@ Acme::BCARMER - The great new Acme::BCARMER!
 
 =head1 VERSION
 
-Version 0.02_01
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
